import React, {Component} from 'react';
import {Card, Form, Radio} from 'ola-ui';
import {CategorySelector} from 'ola-ui-jd';
import Immutable from 'immutable';

const items = Immutable.fromJS([
  {
    "name": "一级品类",
    "field": "firstCate",
    "value": [
      {
        "name": "生鲜",
        "code": "12218"
      }
    ],
  },
  {
    "name": "二级品类",
    "field": "secondCate",
    "value": [
      {
        "name": "水果",
        "code": "12221"
      },
      {
        "name": "海鲜水产",
        "code": "12222"
      }
    ],
  },
  {
    "name": "三级品类",
    "field": "thirdCate",
    "value": [
      {
        "name": "水果礼盒/券",
        "code": "13572"
      },
      {
        "name": "贝类",
        "code": "12244"
      }
    ],
  },
  {
    "name": "分类",
    "field": "category_extcateid",
    "value": [],
  },
  {
    "name": "品牌",
    "field": "brandId",
    "value": [
      {
        "name": "思念",
        "code": "16290"
      },
      {
        "name": "乾越（QIANYUE）",
        "code": "199953"
      },
      {
        "name": "杏花楼",
        "code": "18703"
      }
    ],
  }
]);

let cateInitialValue = Immutable.Map();
let labels = Immutable.Map();

items.map(item => {
  cateInitialValue = cateInitialValue.set(item.get('field'), item.get('value'));
  labels = labels.set(item.get('field'), item.get('name'));
});

@Form.create()
export default class Demo extends Component {

  state = {
    layout: 'vertical'
  };

  render() {

    const {form: {getFieldDecorator, getFieldValue}} = this.props;
    const {layout} = this.state;

    return (
      <div>
        <Radio.Group onChange={({target: {value}}) => {
          this.setState({layout: value});
        }} value={layout}>
          <Radio.Button value="horizontal">水平</Radio.Button>
          <Radio.Button value="vertical">垂直</Radio.Button>
        </Radio.Group>

        <Form>
          <Form.Item label={'品类 / 品牌'} colon={false}>
            {getFieldDecorator('field', {
              initialValue: cateInitialValue
            })(<CategorySelector
              url={'//bi.ola.jd.com/cateBrand/list'}
              layout={layout}
              itemGap={10}
              colProps={{
                span: 4
              }}
              labels={labels}
            />)}
          </Form.Item>

          <Card title="输出">
            {JSON.stringify(getFieldValue('field').toJSON())}
          </Card>

        </Form>
      </div>
    );
  }
}
