# DataSource

可配置数据源的组件

DataSource 是一个为组件提供数据访问能力的高阶组件，通常，经过 DataSource 修饰的组件可以

1. 定义数据访问时机

2. 通过 props 获取响应状态、响应结果及异常信息

3. 作为子组件时的数据配置能力

4. 异步加载与渲染

## 示例

  <demo src="basic.jsx" title="基础用法"></demo>

## API

### 参数

组件通过参数中定义的 prop 来获取 DataSource 提供的相关信息

| 参数 | 说明 | 类型 | 默认值 |
| --- | --- | --- | --- |
| prop | 注入到被修饰组件的 props 中的 key | String | - |

#### props[prop]

DataSource 注入到 props[prop] 中的内容

| key | 说明 | 类型 |
| --- | --- | --- |
| payload | 请求响应的实际内容 | Immutable |
| fetch / update | 发起请求 | function(Object data) |
| loading | 请求中 | bool |
| error | 异常信息 | object |

在组件中获取数据:

```js
import {DataSource} from 'ola-ui-jd';

@DataSource({
  prop: 'list'
})
class WithDataSource extends Component {

  state = {};

  render() {
    const {list: {payload, fetch, update, loading, error}} = this.props;
  }

}
```

### props

组件通过 props 影响 DataSource 的行为

| 参数 | 说明 | 类型 | 默认值 |
| --- | --- | --- | --- |
| dataSource | 数据源地址 | String | - |
| dataSourceFetchOptions | 异步请求配置，传递给 [Ajax](/docs/ola-toolkit/component/ajax) 组件的参数 | object | - |
| dataSourceReqProcessor | 数据请求处理函数，返回请求的数据，`false` 则终止请求发送 | function(data) | - |
| dataSourceRspProcessor | 数据响应处理函数 | function(Immutable data) | - |
| dataSourceValues | 请求携带的数据 | Object | - |
| dataSourceHttpMethod | 请求方法 | String | 'GET' |
| dataSourceFetchTiming | 请求发起时机 | enum {'init', 'auto', 'manual'} | 'auto' |

dataSourceFetchTiming 渲染与请求发起时机

| 类型 | 说明 |
| --- | --- |
| init | 组件被装载 |
| auto | 自动，组件被装载且位于视窗内 |
| manual | 手动控制（调用 fetch 方法） |
