import React, {Component} from 'react';
import {DataSource} from 'ola-ui-jd';
import Immutable from 'immutable';
import {List} from "ola-ui";

@DataSource({
  prop: 'list'
})
class WithDataSource extends Component {

  static defaultProps = {
    dataSource: '//you.jd.com/api/trial/getTrialList.html',
    dataSourceFetchTiming: 'auto',
    dataSourceValues: {page: 1},
    dataSourceFetchOptions: {
      withCredentials: false,
      dataKey: 'result',
    },
  };

  state = {};

  render() {
    const {list: {payload, update, loading, error}} = this.props;
    const taskList = payload.get('trialActivityList') || Immutable.List();
    const page = payload.get('page') || Immutable.Map();

    return <List
      bordered={true}
      loading={loading}
      dataSource={taskList}
      renderItem={item => (<List.Item>{item.get('startTime')} - {item.get('title')}</List.Item>)}
      pagination={page.size && {
        onChange: (page) => {
          update({page});
        },
        total: page.get('totalCount'),
        pageSize: page.get('pageSize'),
        current: page.get('pageNo'),
      }}
    />;
  }

}

// 调用
export default class Demo extends Component {

  state = {};

  static propTypes = {};

  render() {
    return <div>
      {Array(30).fill().map((i, k) => {
        return <p key={k}>异步加载...{50 - k}</p>;
      })}
      <WithDataSource/>
    </div>
  }
}
