'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

exports.default = UploadProps;

var _Message = require('ola-ui/lib/components/Message');

var _Message2 = _interopRequireDefault(_Message);

var _olaToolkit = require('ola-toolkit');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function UploadProps(options) {
  options = (0, _assign2.default)({
    max: 1,
    listType: 'text',
    customRequest: function customRequest(_ref) {
      var action = _ref.action,
          _ref$data = _ref.data,
          data = _ref$data === undefined ? {} : _ref$data,
          file = _ref.file,
          filename = _ref.filename,
          headers = _ref.headers,
          onError = _ref.onError,
          _onProgress = _ref.onProgress,
          onSuccess = _ref.onSuccess,
          withCredentials = _ref.withCredentials;

      var formData = new FormData();

      var field = [];

      if (data) {
        (0, _keys2.default)(data).map(function (key) {
          field.push({
            key: key,
            value: data[key]
          });
        });
      }

      _olaToolkit.Ajax.post({
        field: field,
        attach: [{ key: options.fileKey, value: file }],
        url: action,
        withCredentials: true,
        headers: headers,
        onProgress: function onProgress(_ref2) {
          var percent = _ref2.percent;

          _onProgress({ percent: percent }, file);
        },
        beforeSend: function beforeSend() {
          options.beforeSend();
        }
      }).then(function (response) {
        onSuccess(response, file);
      }).catch(function (err) {
        onError(err.e, err.msg);
      }).finally(function () {
        options.complete();
      });
    }
  }, options);

  var removeFile = function removeFile(file, fileList) {
    var nextFileList = fileList.filter(function (item) {
      return item.uid !== file.uid;
    });
    options.onChange && options.onChange(nextFileList, fileList, file.status);
  };

  var onErrorHandler = function onErrorHandler(file, fileList) {
    var pathname = file.name;
    // 兼容鉴权异常信息
    _Message2.default.error(file.response || pathname + ' \u4E0A\u4F20\u5931\u8D25\uFF01');
    // 错误回调
    options.onError && options.onError(file, fileList);
    removeFile(file, fileList);
  };

  var setting = {
    props: {
      name: 'file',
      action: options.url,
      multiple: false,
      listType: options.listType,
      customRequest: options.customRequest,
      fileList: options.fileList,
      className: options.className,
      data: options.data,
      beforeUpload: function beforeUpload(file, fileList) {
        var accept = options.accept;
        var name = file.name;
        var nameStringList = name.split('.');
        var fileSuffix = nameStringList[nameStringList.length - 1];

        // 格式校验
        if (!accept.includes(fileSuffix.toLocaleLowerCase())) {
          _Message2.default.error('\u53EA\u5141\u8BB8\u4E0A\u4F20' + accept.join(',') + '\u683C\u5F0F\u7684\u6587\u4EF6');
          return false;
        }

        // 上传数量校验
        if (options.fileList.length > options.max - 1) {
          _Message2.default.error('\u6700\u591A\u53EA\u80FD\u4E0A\u4F20' + options.max + '\u4E2A\u6587\u4EF6');
          return false;
        }

        // 文件体积限制
        var curretSize = file.size / 1024;
        if (options.maxSize && curretSize > options.maxSize) {
          _Message2.default.error('\u6587\u4EF6\u5927\u5C0F\u8D85\u51FA\u9650\u5236\uFF0C\u6587\u4EF6\u6700\u5927\u4E0A\u4F20\u4F53\u79EF\u4E3A ' + options.maxSize + 'KB');
          return false;
        }

        return true;
      },
      onChange: function onChange(_ref3) {
        var file = _ref3.file,
            fileList = _ref3.fileList;


        if (file.status == 'uploading') {
          options.onChange && options.onChange(fileList, fileList, file.status);
          options.onUploading && options.onUploading(fileList);
        }

        if (file.status === 'done') {
          _Message2.default.success(file.name + ' \u4E0A\u4F20\u6210\u529F\uFF01');
          fileList.some(function (curFile, index) {
            if (file.uid === curFile.uid) {
              if (file.response.url) {
                fileList[index].url = file.response.url;
              }
              if (file.response.name) {
                fileList[index].name = file.response.name;
              }
              return true;
            }
          });
          options.onChange && options.onChange(fileList, fileList, file.status);
          options.onSuccess && options.onSuccess(file, fileList);
        } else if (file.status === 'error') {
          onErrorHandler(file, fileList);
        }
      },

      onRemove: function onRemove(file) {
        if (!options.loading) {
          var fileList = options.fileList;
          removeFile(file, fileList);
          options.onRemove && options.onRemove(file, fileList);
        }
      }
    }
  };

  return setting;
}
module.exports = exports['default'];